<?php
/**
* Team Section options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Team Section enable section
$wp_customize->add_section( 'graduate_pro_team_section', array(
	'title'             => esc_html__( 'Team Section','graduate-pro' ),
	'description'		=> sprintf( '<b>%1$s:</b> %2$s', esc_html__( 'Info', 'graduate-pro' ), esc_html__( ' New Custom Category ( Taxonomy ) will be added automatically to Content Type as its registered. To see list of custom categories ( Terms ), select custom category in content type and save. Then refresh the page to see the list of custom categories.', 'graduate-pro' ) ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Team Section enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[team_section_enable]', array(
	'default'           => $options['team_section_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_team_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Team Section type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[team_section_content_type]', array(
	'default'           => $options['team_section_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[team_section_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_team_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_team_section_active',
	'choices'         	=> graduate_pro_information_taxonomy_content_type()
) );

// Category Content Type
$wp_customize->add_setting(  'graduate_pro_theme_options[team_section_content_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Category_Control ( $wp_customize,'graduate_pro_theme_options[team_section_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'graduate-pro' ),
	'section'           => 'graduate_pro_team_section',
	'type'              => 'dropdown-category',
	'active_callback'	=> 'graduate_pro_is_team_section_category_active'
) ) );

// Taxonomy Content Type
$wp_customize->add_setting(  'graduate_pro_theme_options[team_section_'. $options['team_section_content_type'] .']', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new graduate_Pro_Dropdown_Taxonomies_Control ( $wp_customize,'graduate_pro_theme_options[team_section_'. $options['team_section_content_type'] .']', array(
	'label'             => esc_html__( 'Select Term', 'graduate-pro' ),
	'section'           => 'graduate_pro_team_section',
	'taxonomy'          => $options['team_section_content_type'],
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'graduate_pro_is_team_section_taxonomy_active'
) ) );

// Add Team Section Count.
$wp_customize->add_setting( 'graduate_pro_theme_options[team_section_count]', array(
	'default'           => $options['team_section_count'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_team_section_count',

) );

$wp_customize->add_control( 'graduate_pro_theme_options[team_section_count]', array(
	'label'           	=> esc_html__( 'No of Posts', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_team_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'graduate_pro_is_team_section_not_demo',
	'input_attrs'		=> array(
		'max'	=> 15,
		'min'	=> 1,
		'style'	=> 'width:100px'
		)
) );