<?php
/**
* Customizer validation functions
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/
if ( ! function_exists( 'graduate_pro_validate_long_excerpt' ) ) :
    /**
     * Check the value for excerpt
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_long_excerpt( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 5 ) {
            $validity->add( 'min_no_of_words', esc_html__( 'Minimum no of words is 5', 'graduate-pro' ) );
        } elseif ( $value > 100 ) {
            $validity->add( 'max_no_of_words', esc_html__( 'Maximum no of words is 100', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_post_id' ) ) :
    /**
     * Check the value for post id
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_post_id( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_post_id', esc_html__( 'Post ID should be more than 1.', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_top_bar_detail_count' ) ) :
    /**
     * Check the value for number of details to show in top bar
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_top_bar_detail_count( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_no_of_details', esc_html__( 'Minimum no of details is 1', 'graduate-pro' ) );
        } elseif ( $value > 3 ) {
            $validity->add( 'max_no_of_details', esc_html__( 'Maximum no of details is 3', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;


if ( ! function_exists( 'graduate_pro_validate_no_of_slider' ) ) :
    /**
     * Check the value for number of slider to show
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_no_of_slider( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_no_of_words', esc_html__( 'Minimum no of slide is 1', 'graduate-pro' ) );
        } elseif ( $value > 5 ) {
            $validity->add( 'max_no_of_words', esc_html__( 'Maximum no of slide is 5', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_about_content_excerpt_length' ) ) :
    /**
     * Check the value for excerpt length for about content
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_about_content_excerpt_length( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 25 ) {
            $validity->add( 'min_words_about_content', esc_html__( 'Minimum no of words is 25', 'graduate-pro' ) );
        } elseif ( $value > 100 ) {
            $validity->add( 'max_words_about_content', esc_html__( 'Maximum no of words is 100', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_trending_course_count' ) ) :
    /**
     * Check the value for no of content in trending course
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_trending_course_count( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 2 ) {
            $validity->add( 'min_no_of_trending_course', esc_html__( 'Minimum no of posts is 2', 'graduate-pro' ) );
        } elseif ( $value > 8 ) {
            $validity->add( 'max_no_of_trending_course', esc_html__( 'Maximum no of posts is 8', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_top_destination_count' ) ) :
    /**
     * Check the value for no of content in top destination
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_top_destination_count( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 6 ) {
            $validity->add( 'min_no_of_top_destination', esc_html__( 'Minimum no of posts is 6', 'graduate-pro' ) );
        } elseif ( $value > 12 ) {
            $validity->add( 'max_no_of_top_destination', esc_html__( 'Maximum no of posts is 12', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_client_section_count' ) ) :
    /**
     * Check the value for no of content in client section
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_client_section_count( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_no_of_clients', esc_html__( 'Minimum no of Clients is 1', 'graduate-pro' ) );
        } elseif ( $value > 15 ) {
            $validity->add( 'max_no_of_clients', esc_html__( 'Maximum no of Clients is 15', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_social_section_count' ) ) :
    /**
     * Check the value for no of links in social section
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_social_section_count( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_no_of_social_links', esc_html__( 'Minimum no of Social Links is 1', 'graduate-pro' ) );
        } elseif ( $value > 10 ) {
            $validity->add( 'max_no_of_social_links', esc_html__( 'Maximum no of Social Links is 10', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_no_of_testimonial' ) ) :
    /**
     * Check the value for number of testimonial to show
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_no_of_testimonial( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_no_of_words', esc_html__( 'Minimum no of testimonial is 1', 'graduate-pro' ) );
        } elseif ( $value > 5 ) {
            $validity->add( 'max_no_of_words', esc_html__( 'Maximum no of testimonial is 5', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;

if ( ! function_exists( 'graduate_pro_validate_counter_value' ) ) :
    /**
     * Check the value for counter
     *
     * @since Graduate Pro 1.0
     * @return string A source value for use
     */
    function graduate_pro_validate_counter_value( $validity, $value ){
        $value = intval( $value );
        if ( empty( $value ) || ! is_numeric( $value ) ) {
            $validity->add( 'required', esc_html__( 'You must supply a valid number.', 'graduate-pro' ) );
        } elseif ( $value < 1 ) {
            $validity->add( 'min_value', esc_html__( 'Value should be more than 1.', 'graduate-pro' ) );
        }
        return $validity;
    }
endif;