<?php
/**
 * counter section
 *
 * This is the template for the content of counter section
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */
if ( ! function_exists( 'graduate_pro_add_counter_section' ) ) :
  /**
   * Add counter section
   *
   *@since Graduate Pro 1.0
   */
  function graduate_pro_add_counter_section() {

    // Check if counter is enabled on frontpage
    $counter_enable = apply_filters( 'graduate_pro_section_status', true, 'counter_content_enable' );
    if ( true !== $counter_enable ) {
      return false;
    }

    // Get counter section details
    $section_details = array();
    $section_details = apply_filters( 'graduate_pro_filter_counter_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render counter section now.
    graduate_pro_render_counter_section( $section_details );
  }
endif;
add_action( 'graduate_pro_primary_content', 'graduate_pro_add_counter_section', 95 );


if ( ! function_exists( 'graduate_pro_get_counter_section_details' ) ) :
  /**
   * counter section details.
   *
   * @since Graduate Pro 1.0
   * @param array $input counter section details.
   */
  function graduate_pro_get_counter_section_details( $input ) {
    $options = graduate_pro_get_theme_options();

    // counter type
    $counter_type  = $options['counter_content_type'];

    $content = array();
    switch ( $counter_type ) {
      case 'demo':
          $content[0]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/counter-section-bg.jpg';
          $content[0]['url']          = '#';
          $content[0]['title']        = esc_html__( 'We help you to grow!', 'graduate-pro' );
          $content[0]['excerpt']      = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut rutrum vel eros at facilisis. Nunc a vulputate elit, et consequat nunc. Ut tellus lectus, efficitur et ultricies vel, fringilla sit amet ligula.', 'graduate-pro' );
          $content[0]['alt']          = esc_attr__( 'Counter Image', 'graduate-pro' );
      break;

      case 'page':
        $id = null;
        if ( isset( $options[ 'counter_content_page'] ) ) {
            $id = $options[ 'counter_content_page'];
        }

        // Bail if no valid pages are selected.
        if ( empty( $id ) ) {
            return $input;
        }

        $args = array(
            'no_found_rows'  => true,
            'post_type'      => 'page',
            'post__in'       => array( absint( $id ) ),
        );
      break;

      case 'post':
        $id = null;
        if ( isset( $options[ 'counter_content_post'] ) ) {
            $id = $options[ 'counter_content_post'];
        }

        // Bail if no valid pages are selected.
        if ( empty( $id ) ) {
            return $input;
        }

        $args = array(
            'no_found_rows'  => true,
            'post_type'      => 'post',
            'post__in'       => array( absint( $id ) ),
        );
      break;

      default:
      break;
    }

    if ( 'demo' != $counter_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'graduate_pro_counter' );
            } else {
                $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1200x500.jpg';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $content[$i]['url']      = get_permalink( $page_id );
            $content[$i]['title']    = get_the_title( $page_id );
            $content[$i]['excerpt']  = graduate_pro_trim_content( 40, $post  );
            $content[$i]['alt']      = get_the_title( $page_id );

            $i++;
          }
          wp_reset_postdata();
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// counter section content details.
add_filter( 'graduate_pro_filter_counter_section_details', 'graduate_pro_get_counter_section_details' );


if ( ! function_exists( 'graduate_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Graduate Pro 1.0
   *
   */
   function graduate_pro_render_counter_section( $content_details = array() ) {
        $options  = graduate_pro_get_theme_options();
        $read_more = ! empty( $options['counter_btn_label'] ) ? $options['counter_btn_label'] : esc_html__( 'Read More', 'graduate-pro' );

        if ( empty( $content_details ) ) {
          return;
        } ?>

        <section id="counter-section">
            <?php foreach ( $content_details as $content_detail ) : ?>
                <div class="counter-featured-image" style="background-image:url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>');">
                    <div class="black-overlay"></div>
                    <div class="container">
                        <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                            </header>
                        <?php endif; 

                        if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                            <div class="entry-content">
                                <?php echo esc_html( $content_detail['excerpt'] ); ?> 
                            </div><!-- .entry-content -->
                        <?php endif; 

                        if ( ! empty( $content_detail['url'] ) ) : ?>
                            <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="view-more"><?php echo esc_html( $read_more ); ?></a>
                        <?php endif; ?>
                    </div><!-- .container -->
                </div><!-- .counter-featured-image -->
            <?php endforeach; 

            if ( true == $options['counter_box_enable'] ) : ?>
                <div class="stat-counter">
                    <div class="container">
                        <div class="statscounts">
                            <?php for ( $i = 1; $i <= 4; $i++ ) { 
                                if ( ! empty( $options['counter_box_count_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) :
                                ?>
                                    <div class="statwrap">
                                        <span class="stat-count"><?php echo absint( $options['counter_box_count_' . $i] ); ?></span>
                                        <small><?php echo esc_html( $options['counter_label_' . $i] ); ?></small>
                                    </div><!-- .statwrap -->
                                <?php endif; 
                            } ?>
                        </div><!-- .statscounts -->
                    </div><!-- .container -->
                </div><!-- .stat-counter -->
            <?php endif; ?>
        </section><!-- #counter-section -->
<?php 
    }
endif;