<?php
/**
 * Template Name: Contact Page Template
 * The template for displaying all pages.
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Graduate_Pro
 */

get_header(); 

$options = graduate_pro_get_theme_options();

if ( true === apply_filters( 'graduate_pro_filter_frontpage_content_enable', true ) ) : ?>


	<section id="contact-information" class="page-section">
		<div class="container">
			<header class="entry-header wow fadeInDown" data-wow-delay="0.2s" data-wow-duration="0.3s">
				<?php if ( ! empty( $options['contact_page_title'] ) ) : ?>
					<h2 class="entry-title"><?php echo esc_html( $options['contact_page_title'] ); ?></h2>
				<?php endif; 
				if ( ! empty( $options['contact_page_description'] ) ) :?>
					<p class="description"><?php echo esc_html( strip_tags( htmlspecialchars_decode( $options['contact_page_description'] ) ) ); ?></p>
				<?php endif; ?>
			</header><!--.entry-header-->

			<div class="entry-content two-columns wow fadeInUp" data-wow-delay="0.2s" data-wow-duration="0.3s">
				<div class="column-wrapper two-col">
					<h3><?php _e( 'Send Us a Message', 'graduate-pro' ); ?></h3>
					<?php if ( ! empty( $options['contact_page_form'] ) ) :
						// var_dump($options['contact_page_form']);
						echo do_shortcode( wp_kses_post( $options['contact_page_form'] ) );
					endif; ?>
				</div><!--.column-wrapper-->

				<div class="column-wrapper">
					<div class="contact-info">
						<h3><?php _e( 'Contact Info', 'graduate-pro' ); ?></h3>
						<ul>
							<?php if ( ! empty( $options['contact_page_location'] ) ) : ?>
								<li><i class="fa fa-map-marker"></i><span><?php echo esc_html( $options['contact_page_location'] ); ?></span></li>
							<?php endif; 
							if ( ! empty( $options['contact_page_phone'] ) ) : ?>
								<li><a href="tel:<?php echo absint( preg_replace( '/\D+/', '', $options['contact_page_phone'] ) ); ?>"><i class="fa fa-phone"></i><?php echo esc_html( $options['contact_page_phone'] ); ?></a></li>
							<?php endif; 
							if ( ! empty( $options['contact_page_pobox'] ) ) : ?>
								<li><i class="fa fa-envelope-square"></i><?php echo esc_html( $options['contact_page_pobox'] ); ?></li>
							<?php endif; 
							if ( ! empty( $options['contact_page_email'] ) ) : ?>
								<li><a href="mailto:<?php echo esc_attr( $options['contact_page_email'] ); ?>"><i class="fa fa-envelope"></i><?php echo esc_html( $options['contact_page_email'] ); ?></a></li>
							<?php endif; ?>
						</ul>
					</div><!--.contact-info-->
					<div class="social-link clear">
						<h3><?php _e( 'Get Social', 'graduate-pro' ); ?></h3>
						<ul class="social-icon">
							<?php for ( $i = 1; $i <= $options['contact_page_social_count']; $i++ ) { 
								if( ! empty( $options['contact_page_social_' . $i ] ) ) : ?>
									<li><a href="<?php echo esc_url(  $options['contact_page_social_' . $i ] ); ?>"></a></li>
								<?php endif;
							} ?>
						</ul>
					</div>
				</div><!--.column-wrapper-->
			</div><!--.entry-content-->
		</div><!--.container-->
	</section><!--#contact-information-->
	<?php
	if ( $options['contact_page_map'] === true ) :
		$map_section_title      = ! empty( $options['map_section_title'] ) ? $options['map_section_title'] : '';
		$map_section_type 	= ! empty( $options['map_section_content_type'] ) ? $options['map_section_content_type'] : '';
		$map_section_embed 	= ! empty( $options['map_section_embed'] ) ? $options['map_section_embed'] : '';
	    $map_section_shortcode  = ! empty( $options['map_section_shortcode'] ) ? $options['map_section_shortcode'] : '';
	    if( ! empty( $map_section_shortcode ) || ! empty( $map_section_embed ) ) : ?>
		    <section id="map-section">
		    	<?php if( ! empty( $map_section_title ) ) : ?>
	                <header class="entry-header wow fadeInDown" data-wow-delay="0.1s" data-wow-duration="0.3s">
	                    <h2 class="entry-title color-black"><?php echo esc_html( $map_section_title ); ?></h2>
	                </header><!--.entry-header-->
	            <?php endif; ?>
	            <div class="entry-content">
	                <div class="wow fadeInUp" data-wow-delay="0.1s" data-wow-duration="0.3s">
	                    <?php 
	                    if ( $map_section_type == 'shortcode' ){
	                        echo do_shortcode( $map_section_shortcode );
	                    } elseif ( $map_section_type == 'embed'  ) {
	                        echo html_entity_decode( $map_section_embed );
	                    }
	                    ?>
	                </div>
	            </div><!--.entry-content-->
		    </section><!--#map-section-->
	    <?php endif; 
    endif;
endif;
get_footer();
